@@ -1,10 +1,9 @@
-
+use crate::CountryCode;
 use phf::phf_map;
 use phf::Map;
-use crate::CountryCode;
 
 /// Data for each Country Code defined by ISO 3166-1
-#[derive(Debug,Copy, Clone)]
+#[derive(Debug, Copy, Clone)]
 pub struct CountryCode3 {
     ///ISO 3166-3 code
     pub code: &'static str,
@@ -18,10 +17,8 @@ pub struct CountryCode3 {
     pub validity: &'static [i32],
     ///Decription
     pub desc: &'static str,
-   
 }
 
-
 pub const BQAQ: CountryCode3 = CountryCode3 {
     code: "BQAQ",
     name: "British Antarctic Territory",
@@ -31,21 +28,16 @@ pub const BQAQ: CountryCode3 = CountryCode3 {
         alpha3: "ATB",
         numeric: 0,
     },
-    validity: &[1974,1979],
+    validity: &[1974, 1979],
     desc: "Merged into Antarctica ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Antarctica",
         alpha2: "AQ",
         alpha3: "ATA",
-        numeric: 010,
-},
-
-    ],
+        numeric: 10,
+    }],
 };
 
-
 pub const BUMM: CountryCode3 = CountryCode3 {
     code: "BUMM",
     name: "Burma",
@@ -55,21 +47,16 @@ pub const BUMM: CountryCode3 = CountryCode3 {
         alpha3: "BUR",
         numeric: 104,
     },
-    validity: &[1974,1989],
+    validity: &[1974, 1989],
     desc: "Name changed to Myanmar ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Myanmar",
         alpha2: "MM",
         alpha3: "MMR",
         numeric: 104,
-},
-
-    ],
+    }],
 };
 
-
 pub const BYAA: CountryCode3 = CountryCode3 {
     code: "BYAA",
     name: "Byelorussian SSR",
@@ -79,21 +66,16 @@ pub const BYAA: CountryCode3 = CountryCode3 {
         alpha3: "BYS",
         numeric: 112,
     },
-    validity: &[1974,1992],
+    validity: &[1974, 1992],
     desc: "Name changed to Belarus ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Belarus",
         alpha2: "BY",
         alpha3: "BLR",
         numeric: 112,
-},
-
-    ],
+    }],
 };
 
-
 pub const CTKI: CountryCode3 = CountryCode3 {
     code: "CTKI",
     name: "Canton and Enderbury Islands",
@@ -103,21 +85,16 @@ pub const CTKI: CountryCode3 = CountryCode3 {
         alpha3: "CTE",
         numeric: 128,
     },
-    validity: &[1974,1984],
+    validity: &[1974, 1984],
     desc: "Merged into Kiribati ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Kiribati",
         alpha2: "KI",
         alpha3: "KIR",
         numeric: 296,
-},
-
-    ],
+    }],
 };
 
-
 pub const CSHH: CountryCode3 = CountryCode3 {
     code: "CSHH",
     name: "Czechoslovakia",
@@ -127,27 +104,24 @@ pub const CSHH: CountryCode3 = CountryCode3 {
         alpha3: "CSK",
         numeric: 200,
     },
-    validity: &[1974,1993],
+    validity: &[1974, 1993],
     desc: "Divided into: Czechia  Slovakia ",
     new_countries: &[
-
- CountryCode {
-        name: "Czechia",
-        alpha2: "CZ",
-        alpha3: "CZE",
-        numeric: 203,
-},
- CountryCode {
-        name: "Slovakia",
-        alpha2: "SK",
-        alpha3: "SVK",
-        numeric: 703,
-},
-
+        CountryCode {
+            name: "Czechia",
+            alpha2: "CZ",
+            alpha3: "CZE",
+            numeric: 203,
+        },
+        CountryCode {
+            name: "Slovakia",
+            alpha2: "SK",
+            alpha3: "SVK",
+            numeric: 703,
+        },
     ],
 };
 
-
 pub const DYBJ: CountryCode3 = CountryCode3 {
     code: "DYBJ",
     name: "Dahomey",
@@ -157,21 +131,16 @@ pub const DYBJ: CountryCode3 = CountryCode3 {
         alpha3: "DHY",
         numeric: 204,
     },
-    validity: &[1974,1977],
+    validity: &[1974, 1977],
     desc: "Name changed to Benin ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Benin",
         alpha2: "BJ",
         alpha3: "BEN",
         numeric: 204,
-},
-
-    ],
+    }],
 };
 
-
 pub const NQAQ: CountryCode3 = CountryCode3 {
     code: "NQAQ",
     name: "Dronning Maud Land",
@@ -181,21 +150,16 @@ pub const NQAQ: CountryCode3 = CountryCode3 {
         alpha3: "ATN",
         numeric: 216,
     },
-    validity: &[1974,1983],
+    validity: &[1974, 1983],
     desc: "Merged into Antarctica ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Antarctica",
         alpha2: "AQ",
         alpha3: "ATA",
-        numeric: 010,
-},
-
-    ],
+        numeric: 10,
+    }],
 };
 
-
 pub const TPTL: CountryCode3 = CountryCode3 {
     code: "TPTL",
     name: "East Timor",
@@ -205,21 +169,16 @@ pub const TPTL: CountryCode3 = CountryCode3 {
         alpha3: "TMP",
         numeric: 626,
     },
-    validity: &[1974,2002],
+    validity: &[1974, 2002],
     desc: "Name changed to Timor-Leste ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Timor-Leste",
         alpha2: "TL",
         alpha3: "TLS",
         numeric: 626,
-},
-
-    ],
+    }],
 };
 
-
 pub const FXFR: CountryCode3 = CountryCode3 {
     code: "FXFR",
     name: "France, Metropolitan",
@@ -229,21 +188,16 @@ pub const FXFR: CountryCode3 = CountryCode3 {
         alpha3: "FXX",
         numeric: 249,
     },
-    validity: &[1993,1997],
+    validity: &[1993, 1997],
     desc: "Merged into France ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "France",
         alpha2: "FR",
         alpha3: "FRA",
         numeric: 250,
-},
-
-    ],
+    }],
 };
 
-
 pub const AIDJ: CountryCode3 = CountryCode3 {
     code: "AIDJ",
     name: "French Afars and Issas",
@@ -253,21 +207,16 @@ pub const AIDJ: CountryCode3 = CountryCode3 {
         alpha3: "AFI",
         numeric: 262,
     },
-    validity: &[1974,1977],
+    validity: &[1974, 1977],
     desc: "Name changed to Djibouti ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Djibouti",
         alpha2: "DJ",
         alpha3: "DJI",
         numeric: 262,
-},
-
-    ],
+    }],
 };
 
-
 pub const FQHH: CountryCode3 = CountryCode3 {
     code: "FQHH",
     name: "French Southern and Antarctic Territories",
@@ -277,27 +226,24 @@ pub const FQHH: CountryCode3 = CountryCode3 {
         alpha3: "ATF",
         numeric: 0,
     },
-    validity: &[1974,1979],
+    validity: &[1974, 1979],
     desc: "Divided into: Part of Antarctica   French Southern Territories ",
     new_countries: &[
-
- CountryCode {
-        name: "Part of Antarctica",
-        alpha2: "AQ",
-        alpha3: "ATA",
-        numeric: 010,
-},
- CountryCode {
-        name: "French Southern Territories",
-        alpha2: "TF",
-        alpha3: "ATF",
-        numeric: 260,
-},
-
+        CountryCode {
+            name: "Part of Antarctica",
+            alpha2: "AQ",
+            alpha3: "ATA",
+            numeric: 10,
+        },
+        CountryCode {
+            name: "French Southern Territories",
+            alpha2: "TF",
+            alpha3: "ATF",
+            numeric: 260,
+        },
     ],
 };
 
-
 pub const DDDE: CountryCode3 = CountryCode3 {
     code: "DDDE",
     name: "German Democratic Republic",
@@ -307,21 +253,16 @@ pub const DDDE: CountryCode3 = CountryCode3 {
         alpha3: "DDR",
         numeric: 278,
     },
-    validity: &[1974,1990],
+    validity: &[1974, 1990],
     desc: "Merged into Germany ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Germany",
         alpha2: "DE",
         alpha3: "DEU",
         numeric: 276,
-},
-
-    ],
+    }],
 };
 
-
 pub const GEHH: CountryCode3 = CountryCode3 {
     code: "GEHH",
     name: "Gilbert Islands",
@@ -331,21 +272,16 @@ pub const GEHH: CountryCode3 = CountryCode3 {
         alpha3: "GEL",
         numeric: 296,
     },
-    validity: &[1974,1979],
+    validity: &[1974, 1979],
     desc: "Name changed to Kiribati ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Kiribati",
         alpha2: "KI",
         alpha3: "KIR",
         numeric: 296,
-},
-
-    ],
+    }],
 };
 
-
 pub const JTUM: CountryCode3 = CountryCode3 {
     code: "JTUM",
     name: "Johnston Island",
@@ -355,21 +291,16 @@ pub const JTUM: CountryCode3 = CountryCode3 {
         alpha3: "JTN",
         numeric: 396,
     },
-    validity: &[1974,1986],
+    validity: &[1974, 1986],
     desc: "Merged into United States Minor Outlying Islands ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "United States Minor Outlying Islands",
         alpha2: "UM",
         alpha3: "UMI",
         numeric: 581,
-},
-
-    ],
+    }],
 };
 
-
 pub const MIUM: CountryCode3 = CountryCode3 {
     code: "MIUM",
     name: "Midway Islands",
@@ -379,21 +310,16 @@ pub const MIUM: CountryCode3 = CountryCode3 {
         alpha3: "MID",
         numeric: 488,
     },
-    validity: &[1974,1986],
+    validity: &[1974, 1986],
     desc: "Merged into United States Minor Outlying Islands ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "United States Minor Outlying Islands",
         alpha2: "UM",
         alpha3: "UMI",
         numeric: 581,
-},
-
-    ],
+    }],
 };
 
-
 pub const ANHH: CountryCode3 = CountryCode3 {
     code: "ANHH",
     name: "Netherlands Antilles",
@@ -403,33 +329,30 @@ pub const ANHH: CountryCode3 = CountryCode3 {
         alpha3: "ANT",
         numeric: 530,
     },
-    validity: &[1974,2010 ],
+    validity: &[1974, 2010],
     desc: "Divided into: Bonaire, Sint Eustatius and Saba   Curaçao  Sint Maarten  ",
     new_countries: &[
-
- CountryCode {
-        name: "Bonaire, Sint Eustatius and Saba",
-        alpha2: "BQ",
-        alpha3: "BES",
-        numeric: 535,
-},
- CountryCode {
-        name: "Curaçao",
-        alpha2: "CW",
-        alpha3: "CUW",
-        numeric: 531,
-},
- CountryCode {
-        name: "Sint Maarten (Dutch part)",
-        alpha2: "SX",
-        alpha3: "SXM",
-        numeric: 534,
-},
-
+        CountryCode {
+            name: "Bonaire, Sint Eustatius and Saba",
+            alpha2: "BQ",
+            alpha3: "BES",
+            numeric: 535,
+        },
+        CountryCode {
+            name: "Curaçao",
+            alpha2: "CW",
+            alpha3: "CUW",
+            numeric: 531,
+        },
+        CountryCode {
+            name: "Sint Maarten (Dutch part)",
+            alpha2: "SX",
+            alpha3: "SXM",
+            numeric: 534,
+        },
     ],
 };
 
-
 pub const NTHH: CountryCode3 = CountryCode3 {
     code: "NTHH",
     name: "Neutral Zone",
@@ -439,27 +362,24 @@ pub const NTHH: CountryCode3 = CountryCode3 {
         alpha3: "NTZ",
         numeric: 536,
     },
-    validity: &[1974,1993],
+    validity: &[1974, 1993],
     desc: "Divided into: Part of Iraq  Part of Saudi Arabia ",
     new_countries: &[
-
- CountryCode {
-        name: "Part of Iraq",
-        alpha2: "IQ",
-        alpha3: "IRQ",
-        numeric: 368,
-},
- CountryCode {
-        name: "Part of Saudi Arabia",
-        alpha2: "SA",
-        alpha3: "SAU",
-        numeric: 682,
-},
-
+        CountryCode {
+            name: "Part of Iraq",
+            alpha2: "IQ",
+            alpha3: "IRQ",
+            numeric: 368,
+        },
+        CountryCode {
+            name: "Part of Saudi Arabia",
+            alpha2: "SA",
+            alpha3: "SAU",
+            numeric: 682,
+        },
     ],
 };
 
-
 pub const NHVU: CountryCode3 = CountryCode3 {
     code: "NHVU",
     name: "New Hebrides",
@@ -469,21 +389,16 @@ pub const NHVU: CountryCode3 = CountryCode3 {
         alpha3: "NHB",
         numeric: 548,
     },
-    validity: &[1974,1980],
+    validity: &[1974, 1980],
     desc: "Name changed to Vanuatu ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Vanuatu",
         alpha2: "VU",
         alpha3: "VUT",
         numeric: 548,
-},
-
-    ],
+    }],
 };
 
-
 pub const PCHH: CountryCode3 = CountryCode3 {
     code: "PCHH",
     name: "Pacific Islands (Trust Territory)",
@@ -493,39 +408,36 @@ pub const PCHH: CountryCode3 = CountryCode3 {
         alpha3: "PCI",
         numeric: 582,
     },
-    validity: &[1974,1986],
+    validity: &[1974, 1986],
     desc: "Divided into: Marshall Islands  Micronesia   Northern Mariana Islands  Palau ",
     new_countries: &[
-
- CountryCode {
-        name: "Marshall Islands",
-        alpha2: "MH",
-        alpha3: "MHL",
-        numeric: 584,
-},
- CountryCode {
-        name: "Micronesia (Federated States of)",
-        alpha2: "FM",
-        alpha3: "FSM",
-        numeric: 583,
-},
- CountryCode {
-        name: "Northern Mariana Islands",
-        alpha2: "MP",
-        alpha3: "MNP",
-        numeric: 580,
-},
- CountryCode {
-        name: "Palau",
-        alpha2: "PW",
-        alpha3: "PLW",
-        numeric: 585,
-},
-
+        CountryCode {
+            name: "Marshall Islands",
+            alpha2: "MH",
+            alpha3: "MHL",
+            numeric: 584,
+        },
+        CountryCode {
+            name: "Micronesia (Federated States of)",
+            alpha2: "FM",
+            alpha3: "FSM",
+            numeric: 583,
+        },
+        CountryCode {
+            name: "Northern Mariana Islands",
+            alpha2: "MP",
+            alpha3: "MNP",
+            numeric: 580,
+        },
+        CountryCode {
+            name: "Palau",
+            alpha2: "PW",
+            alpha3: "PLW",
+            numeric: 585,
+        },
     ],
 };
 
-
 pub const PZPA: CountryCode3 = CountryCode3 {
     code: "PZPA",
     name: "Panama Canal Zone",
@@ -535,21 +447,16 @@ pub const PZPA: CountryCode3 = CountryCode3 {
         alpha3: "PCZ",
         numeric: 0,
     },
-    validity: &[1974,1980],
+    validity: &[1974, 1980],
     desc: "Merged into Panama ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Panama",
         alpha2: "PA",
         alpha3: "PAN",
         numeric: 591,
-},
-
-    ],
+    }],
 };
 
-
 pub const CSXX: CountryCode3 = CountryCode3 {
     code: "CSXX",
     name: "Serbia and Montenegro",
@@ -559,27 +466,24 @@ pub const CSXX: CountryCode3 = CountryCode3 {
         alpha3: "SCG",
         numeric: 891,
     },
-    validity: &[2003,2006],
+    validity: &[2003, 2006],
     desc: "Divided into: Montenegro  Serbia ",
     new_countries: &[
-
- CountryCode {
-        name: "Montenegro",
-        alpha2: "ME",
-        alpha3: "MNE",
-        numeric: 499,
-},
- CountryCode {
-        name: "Serbia",
-        alpha2: "RS",
-        alpha3: "SRB",
-        numeric: 688,
-},
-
+        CountryCode {
+            name: "Montenegro",
+            alpha2: "ME",
+            alpha3: "MNE",
+            numeric: 499,
+        },
+        CountryCode {
+            name: "Serbia",
+            alpha2: "RS",
+            alpha3: "SRB",
+            numeric: 688,
+        },
     ],
 };
 
-
 pub const SKIN: CountryCode3 = CountryCode3 {
     code: "SKIN",
     name: "Sikkim",
@@ -589,21 +493,16 @@ pub const SKIN: CountryCode3 = CountryCode3 {
         alpha3: "SKM",
         numeric: 0,
     },
-    validity: &[1974,1975],
+    validity: &[1974, 1975],
     desc: "Merged into India ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "India",
         alpha2: "IN",
         alpha3: "IND",
         numeric: 356,
-},
-
-    ],
+    }],
 };
 
-
 pub const RHZW: CountryCode3 = CountryCode3 {
     code: "RHZW",
     name: "Southern Rhodesia",
@@ -613,21 +512,16 @@ pub const RHZW: CountryCode3 = CountryCode3 {
         alpha3: "RHO",
         numeric: 716,
     },
-    validity: &[1974,1980],
+    validity: &[1974, 1980],
     desc: "Name changed to Zimbabwe ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Zimbabwe",
         alpha2: "ZW",
         alpha3: "ZWE",
         numeric: 716,
-},
-
-    ],
+    }],
 };
 
-
 pub const PUUM: CountryCode3 = CountryCode3 {
     code: "PUUM",
     name: "United States Miscellaneous Pacific Islands",
@@ -637,21 +531,16 @@ pub const PUUM: CountryCode3 = CountryCode3 {
         alpha3: "PUS",
         numeric: 849,
     },
-    validity: &[1974,1986],
+    validity: &[1974, 1986],
     desc: "Merged into United States Minor Outlying Islands ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "United States Minor Outlying Islands",
         alpha2: "UM",
         alpha3: "UMI",
         numeric: 581,
-},
-
-    ],
+    }],
 };
 
-
 pub const HVBF: CountryCode3 = CountryCode3 {
     code: "HVBF",
     name: "Upper Volta",
@@ -661,21 +550,16 @@ pub const HVBF: CountryCode3 = CountryCode3 {
         alpha3: "HVO",
         numeric: 854,
     },
-    validity: &[1974,1984],
+    validity: &[1974, 1984],
     desc: "Name changed to Burkina Faso ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Burkina Faso",
         alpha2: "BF",
         alpha3: "BFA",
         numeric: 854,
-},
-
-    ],
+    }],
 };
 
-
 pub const SUHH: CountryCode3 = CountryCode3 {
     code: "SUHH",
     name: "USSR",
@@ -693,13 +577,13 @@ pub const SUHH: CountryCode3 = CountryCode3 {
         name: "Armenia",
         alpha2: "AM",
         alpha3: "ARM",
-        numeric: 051,
+        numeric: 51,
 },
  CountryCode {
         name: "Azerbaijan",
         alpha2: "AZ",
         alpha3: "AZE",
-        numeric: 031,
+        numeric: 31,
 },
  CountryCode {
         name: "Estonia",
@@ -771,7 +655,6 @@ pub const SUHH: CountryCode3 = CountryCode3 {
     ],
 };
 
-
 pub const VDVN: CountryCode3 = CountryCode3 {
     code: "VDVN",
     name: "Viet-Nam, Democratic Republic of",
@@ -781,21 +664,16 @@ pub const VDVN: CountryCode3 = CountryCode3 {
         alpha3: "VDR",
         numeric: 0,
     },
-    validity: &[1974,1977],
+    validity: &[1974, 1977],
     desc: "Merged into Viet Nam ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Viet Nam",
         alpha2: "VN",
         alpha3: "VNM",
         numeric: 704,
-},
-
-    ],
+    }],
 };
 
-
 pub const WKUM: CountryCode3 = CountryCode3 {
     code: "WKUM",
     name: "Wake Island",
@@ -805,21 +683,16 @@ pub const WKUM: CountryCode3 = CountryCode3 {
         alpha3: "WAK",
         numeric: 872,
     },
-    validity: &[1974,1986],
+    validity: &[1974, 1986],
     desc: "Merged into United States Minor Outlying Islands ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "United States Minor Outlying Islands",
         alpha2: "UM",
         alpha3: "UMI",
         numeric: 581,
-},
-
-    ],
+    }],
 };
 
-
 pub const YDYE: CountryCode3 = CountryCode3 {
     code: "YDYE",
     name: "Yemen, Democratic",
@@ -829,21 +702,16 @@ pub const YDYE: CountryCode3 = CountryCode3 {
         alpha3: "YMD",
         numeric: 720,
     },
-    validity: &[1974,1990],
+    validity: &[1974, 1990],
     desc: "Merged into Yemen ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Yemen",
         alpha2: "YE",
         alpha3: "YEM",
         numeric: 887,
-},
-
-    ],
+    }],
 };
 
-
 pub const YUCS: CountryCode3 = CountryCode3 {
     code: "YUCS",
     name: "Yugoslavia",
@@ -853,21 +721,16 @@ pub const YUCS: CountryCode3 = CountryCode3 {
         alpha3: "YUG",
         numeric: 891,
     },
-    validity: &[1974,2003],
+    validity: &[1974, 2003],
     desc: "Name changed to Serbia and Montenegro ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Serbia and Montenegro",
         alpha2: "CS",
         alpha3: "SCG",
         numeric: 891,
-},
-
-    ],
+    }],
 };
 
-
 pub const ZRCD: CountryCode3 = CountryCode3 {
     code: "ZRCD",
     name: "Zaire",
@@ -877,21 +740,16 @@ pub const ZRCD: CountryCode3 = CountryCode3 {
         alpha3: "ZAR",
         numeric: 180,
     },
-    validity: &[1974,1997],
+    validity: &[1974, 1997],
     desc: "Name changed to Congo, Democratic Republic of the ",
-    new_countries: &[
-
- CountryCode {
+    new_countries: &[CountryCode {
         name: "Congo, Democratic Republic of the",
         alpha2: "CD",
         alpha3: "COD",
         numeric: 180,
-},
-
-    ],
+    }],
 };
 
-
 /// Returns the CountryCode3 with the given Alpha4 code, if exists.
 /// #Sample
 /// ```
@@ -902,8 +760,7 @@ pub fn from_code(alpha4: &str) -> Option<CountryCode3> {
     ALPHA4_MAP.get(alpha4).cloned()
 }
 
-
-///CountryCode map with  alpha4 Code key 
+///CountryCode map with  alpha4 Code key
 pub const ALPHA4_MAP: Map<&str, CountryCode3> = phf_map! {
 
 "BQAQ" => BQAQ,
@@ -940,41 +797,8 @@ pub const ALPHA4_MAP: Map<&str, CountryCode3> = phf_map! {
 
 };
 
-
 ///ALL the Countrys struct
-pub const ALL: &'static [CountryCode3] = &[
-
-BQAQ,
-BUMM,
-BYAA,
-CTKI,
-CSHH,
-DYBJ,
-NQAQ,
-TPTL,
-FXFR,
-AIDJ,
-FQHH,
-DDDE,
-GEHH,
-JTUM,
-MIUM,
-ANHH,
-NTHH,
-NHVU,
-PCHH,
-PZPA,
-CSXX,
-SKIN,
-RHZW,
-PUUM,
-HVBF,
-SUHH,
-VDVN,
-WKUM,
-YDYE,
-YUCS,
-ZRCD,
-
+pub const ALL: &[CountryCode3] = &[
+    BQAQ, BUMM, BYAA, CTKI, CSHH, DYBJ, NQAQ, TPTL, FXFR, AIDJ, FQHH, DDDE, GEHH, JTUM, MIUM, ANHH,
+    NTHH, NHVU, PCHH, PZPA, CSXX, SKIN, RHZW, PUUM, HVBF, SUHH, VDVN, WKUM, YDYE, YUCS, ZRCD,
 ];
-
